@@ -6,7 +6,7 @@ import socket
 import subprocess
 import tempfile
 import time
-from typing import Any, Dict, List, Mapping, Tuple
+from typing import Any, Dict, List, Literal, Mapping, Tuple
 
 from localstack.constants import (
     AWS_REGION_US_EAST_1,
@@ -353,6 +353,7 @@ DOCKER_BRIDGE_IP = os.environ.get("DOCKER_BRIDGE_IP", "").strip()
 ENABLE_CONFIG_UPDATES = is_env_true("ENABLE_CONFIG_UPDATES")
 
 # CORS settings
+DISABLE_CORS_HEADERS = is_env_true("DISABLE_CORS_HEADERS")
 DISABLE_CORS_CHECKS = is_env_true("DISABLE_CORS_CHECKS")
 DISABLE_CUSTOM_CORS_S3 = is_env_true("DISABLE_CUSTOM_CORS_S3")
 DISABLE_CUSTOM_CORS_APIGATEWAY = is_env_true("DISABLE_CUSTOM_CORS_APIGATEWAY")
@@ -495,6 +496,11 @@ DYNAMODB_SHARE_DB = int(os.environ.get("DYNAMODB_SHARE_DB") or 0)
 # expose SQS on a specific port externally
 SQS_PORT_EXTERNAL = int(os.environ.get("SQS_PORT_EXTERNAL") or 0)
 
+# Strategy used when creating SQS queue urls. can be "off", "domain", or "path"
+SQS_ENDPOINT_STRATEGY: Literal["off", "domain", "path"] = (
+    os.environ.get("SQS_ENDPOINT_STRATEGY", "") or "off"
+)
+
 # host under which the LocalStack services are available from Lambda Docker containers
 HOSTNAME_FROM_LAMBDA = os.environ.get("HOSTNAME_FROM_LAMBDA", "").strip()
 
@@ -609,6 +615,7 @@ CONFIG_ENV_VARS = [
     "DEVELOP",
     "DEVELOP_PORT",
     "DISABLE_CORS_CHECKS",
+    "DISABLE_CORS_HEADERS",
     "DISABLE_CUSTOM_CORS_APIGATEWAY",
     "DISABLE_CUSTOM_CORS_S3",
     "DISABLE_EVENTS",
@@ -654,6 +661,7 @@ CONFIG_ENV_VARS = [
     "LOG_LICENSE_ISSUES",
     "LS_LOG",
     "MAIN_CONTAINER_NAME",
+    "OPENSEARCH_ENDPOINT_STRATEGY",
     "OUTBOUND_HTTP_PROXY",
     "OUTBOUND_HTTPS_PROXY",
     "PERSISTENCE_SINGLE_FILE",
@@ -662,6 +670,7 @@ CONFIG_ENV_VARS = [
     "SERVICES",
     "SKIP_INFRA_DOWNLOADS",
     "SKIP_SSL_CERT_DOWNLOAD",
+    "SQS_ENDPOINT_STRATEGY",
     "SQS_PORT_EXTERNAL",
     "STEPFUNCTIONS_LAMBDA_ENDPOINT",
     "SYNCHRONOUS_API_GATEWAY_EVENTS",
